@@ -30,14 +30,18 @@ def t(arg, *args, **kwargs):
     _classes = re.compile('\.([a-zA-Z0-9\-_]+)')
     _id = re.compile('\#(\w+)')
     _unnamed_attrs = re.compile('\:(\w+)')
-    _named_attrs = re.compile('\[(\w+)="(.*?)"\]')
+    _named_attrs0 = re.compile("""\[([a-zA-Z0-9\-\_]+?)=(.+?)\]""")
+    _named_attrs1 = re.compile("""\[([a-zA-Z0-9\-\_]+?)=\"(.+?)\"\]""")
+    _named_attrs2 = re.compile("""\[([a-zA-Z0-9\-\_]+?)=\'(.+?)\'\]""")
 
     name = _name.findall(arg)[0]
     attributes = dict()
     tag_id = _id.findall(arg)
     tag_classes = _classes.findall(arg)
     tag_unnamed_attrs = _unnamed_attrs.findall(arg)
-    tag_named_attrs = _named_attrs.findall(arg)
+    tag_named_attrs = _named_attrs0.findall(arg)
+    tag_named_attrs += _named_attrs1.findall(arg)
+    tag_named_attrs += _named_attrs2.findall(arg)
 
     unnamed_attributes = tag_unnamed_attrs
     named_attributes = {k: v for k, v in tag_named_attrs}
